==> stellarium_23.4.orig.tar.gz: stellarium-23.4/src/gui/ContributorsList.hpp <==
/*
 * Stellarium
 * Copyright (C) 2022 Alexander Wolf
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
 
#include <QStringList>

namespace StelContributors {

    static const QStringList contributorsList =
    {
        "Fabien Chereau", "Georg Zotti", "Alexander V. Wolf", "Matthew Gates", "Bogdan Marinov", 
        "Rob Spearman", "Marcos Cardinot", "Guillaume Chereau", "Florian Schaukowitsch", "Ferdinand Majerech", 
        "Johannes Gajdosik", "Ruslan Kabatsayev", "Timothy Reaves", "Susanne M Hoffmann", "Tony Furr", 
        "Eleni Maria Stea", "Andrei Borza", "sunshuwei", "Teresa Huertas", "Diego Marcos", 
        "Johan Meuris", "J.L.Canales", "Worachate Boonplod", "Andras Mohari", "Ivan Marti-Vidal", 
        "Nicolas Martignoni", "Michael Storm", "Petr Kubánek", "Holger Nießner", "Yuri Chornoivan", 
        "Simon Parzer", "Qam1", "misibacsi", "Barry Gerdes", "Anton Samoylov", 
        "Adriano Steffler", "Alexey Sokolov", "Khalid AlAjaji", "Minmin Gong", "Alexander Duytschaever", 
        "Nick Fedoseev", "Sibi Antony", "Pluton Helleformer", "Tanmoy Saha", "ultrapre", 
        "Alex Gamper", "Vladislav Bataron", "Alessandro Siniscalchi", "Elaina", "Kutaibaa Akraa", 
        "Peter Mousley", "Andy Kirkham", "Jörg Müller", "Vishvas Vasuki विश्वासः", "Atque", 
        "Peter Vasey", "Rumen Bogdanovski", "Dan Smale", "Hernan Martinez", "henrysky", 
        "FreewareTips", "RVS", "Wolfgang Laun", "Allan Johnson", "Emmanuel", 
        "Greg Alexander", "Michal Sojka", "Peter Walser", "William Formyduval", "uwes-ufo", 
        "Giuseppe Putzolu", "Fòram na Gàidhlig", "Paolo Cancedda (Pac)", "Pawel Stolowski", "Ralph Schäfermeier", 
        "Teemu Nätkinniemi", "Volker Hören", "ChrUnger", "Chris Xiao", "Hleb Valoshka", 
        "Iceflower", "Mircea Lite", "Paul Krizak", "Ray", "Sergej Krivonos", 
        "Shantanu Agarwal", "Nick Kanel", "colossatr0n", "luzpaz", "Martin Bernardi", 
        "Miroslav Broz", "ysjbserver", "Alexandros Kosiaris", "Alexey Dokuchaev", "Aspere", 
        "Clement Sommelet", "Colin Gaudion", "Daniel", "David Baucum", "EuklidAlexandria", 
        "Felix Z", "Freeman Li", "Hans Lambermont", "Jocelyn GIROD", "Kirill Snezhko", 
        "Konrad Rybka", "Maciej Serylak", "Max Digruber", "Norman Rasmussen", "Peter Neubauer", 
        "Robert S. Fuller", "Sergey", "Steven Bellavia", "Victor Reijs", "bv6679", 
        "Daniel Adastra", "sebagr", "tofilwiktor", "Adam Majer", "Alec Clews", 
        "Alexander Belopolsky", "Alexander Miller", "Andrew Jeddeloh", "Angelo Fraietta", "Annette S. Lee", 
        "Antoine Jacoutot", "Arjen de Korte", "Bernd K", "Björn Höfling", "Brian Kloppenborg", 
        "Cassy", "Chi Huynh", "Clepalitto", "Cosimo Cecchi", "Dan Joplin", 
        "Daniel De Mickey", "Daniel Michalik", "Danny Milosavljevic", "Dark Dragon", "Dempsey-p", 
        "Dhia", "Dominik Maximilián Ramík", "François Scholder", "Froenchenko Leonid", "Gion Kunz", 
        "GitHaarek", "Guillaume Communie", "Gábor Péterffy", "Hector Quemada", "Holger", 
        "JAY RESPLER", "JMejuto", "Jack Schmidt", "Jean-Philippe Lambert", "Katrin Leinweber", 
        "Kenan Dervišević", "Louis Strous", "M.S. Adityan", "Martin Bernardi (Laptop)", "Matt Hughes", 
        "Matthias Drochner", "Matwey V. Kornilov", "Michael Dickens", "Michael Taylor", "Mykyta Sytyi", 
        "Nidroide", "Nir Lichtman", "Oleg Ginzburg", "Oscar Roig Felius", "ParkSangJun", 
        "Patrick", "Pavel Klimenko", "Peter", "Peter Hickey", "Pino Toscano", 
        "Roland Bosa", "Sam Lanning", "Sebastian Jennen", "SilverAstro", "Song Li", 
        "Sripath Roy Koganti", "Sveinn í Felli", "Thilo", "Thomas1664", "Tig la Pomme", 
        "Tomasz Buchert", "TotalCaesar659", "Tuomas Teipainen", "Tēvita O. Kaʻili", "Vancho Stojkoski", 
        "Vicente Reyes", "Wonkyo Choe", "Yaakov Selkowitz", "Youssif Ghantous Filho", "Yury Solomonov", 
        "adalava", "afontenot", "bkuhls", "chithihuynh", "Marc Espie", 
        "leonardcj", "luz paz", "Pavel Klimenko", "rikardfalkeborn", "riodoro1", 
        "Ross Mitchell", "Edgar Scholz", "zhu1995zpb", "Łukasz 'sil2100' Zemczak"
    };
    
}

==> stellarium_24.3.orig.tar.gz: stellarium-24.3/src/gui/ContributorsList.hpp <==
/*
 * Stellarium
 * Copyright (C) 2022 Alexander Wolf
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
 
#include <QStringList>

namespace StelContributors {

    static const QStringList contributorsList =
    {
        "Fabien Chereau", "Georg Zotti", "Alexander V. Wolf", "Matthew Gates", "Bogdan Marinov", 
        "Rob Spearman", "Ruslan Kabatsayev", "Marcos Cardinot", "Guillaume Chereau", "Florian Schaukowitsch", 
        "Ferdinand Majerech", "Johannes Gajdosik", "Timothy Reaves", "Susanne M Hoffmann", "Tony Furr", 
        "Eleni Maria Stea", "Andrei Borza", "sunshuwei", "Teresa Huertas", "Diego Marcos", 
        "Johan Meuris", "Worachate Boonplod", "J.L.Canales", "Andras Mohari", "Ivan Marti-Vidal", 
        "Nicolas Martignoni", "Michael Storm", "Petr Kubánek", "Holger Nießner", "Yuri Chornoivan", 
        "Simon Parzer", "Qam1", "misibacsi", "Barry Gerdes", "Anton Samoylov", 
        "Adriano Steffler", "Alexey Sokolov", "Khalid AlAjaji", "Minmin Gong", "Alexander Duytschaever", 
        "Nick Fedoseev", "Sibi Antony", "Pluton Helleformer", "Tanmoy Saha", "ultrapre", 
        "Alex Gamper", "Vladislav Bataron", "Alessandro Siniscalchi", "Elaina", "Kutaibaa Akraa", 
        "Peter Mousley", "Andy Kirkham", "Jörg Müller", "Vishvas Vasuki विश्वासः", "Atque", 
        "Peter Vasey", "Rumen Bogdanovski", "Dan Smale", "Hernan Martinez", "henrysky", 
        "FreewareTips", "RVS", "Wolfgang Laun", "Allan Johnson", "Emmanuel", 
        "Greg Alexander", "Michal Sojka", "Peter Walser", "William Formyduval", "uwes-ufo", 
        "Giuseppe Putzolu", "Fòram na Gàidhlig", "Paolo Cancedda (Pac)", "Pawel Stolowski", "Ralph Schäfermeier", 
        "Teemu Nätkinniemi", "Volker Hören", "ChrUnger", "Chris Xiao", "Hleb Valoshka", 
        "Iceflower", "Mircea Lite", "Paul Krizak", "Ray", "Sergej Krivonos", 
        "Shantanu Agarwal", "Nick Kanel", "colossatr0n", "luzpaz", "Martin Bernardi", 
        "Miroslav Broz", "ysjbserver", "Alexandros Kosiaris", "Alexey Dokuchaev", "Aspere", 
        "Clement Sommelet", "Colin Gaudion", "Daniel", "David Baucum", "EuklidAlexandria", 
        "Felix Z", "Freeman Li", "Hans Lambermont", "Jocelyn GIROD", "Kirill Snezhko", 
        "Konrad Rybka", "Maciej Serylak", "Max Digruber", "Norman Rasmussen", "Peter Neubauer", 
        "Robert S. Fuller", "Sergey", "Steven Bellavia", "Victor Reijs", "bv6679", 
        "Daniel Adastra", "sebagr", "tofilwiktor", "Adam Majer", "Alec Clews", 
        "Alexander Belopolsky", "Alexander Miller", "Andrew Jeddeloh", "Angelo Fraietta", "Annette S. Lee", 
        "Antoine Jacoutot", "Arjen de Korte", "Bernd K", "Björn Höfling", "Brian Kloppenborg", 
        "Cassy", "Chi Huynh", "Clepalitto", "Cosimo Cecchi", "Dan Joplin", 
        "Daniel De Mickey", "Daniel Michalik", "Danny Milosavljevic", "Dark Dragon", "Dempsey-p", 
        "Dhia", "Dominik Maximilián Ramík", "François Scholder", "Froenchenko Leonid", "Gion Kunz", 
        "GitHaarek", "Guillaume Communie", "Gábor Péterffy", "Hector Quemada", "Holger", 
        "JAY RESPLER", "JMejuto", "Jack Schmidt", "Jean-Philippe Lambert", "Katrin Leinweber", 
        "Kenan Dervišević", "Louis Strous", "M.S. Adityan", "Martin Bernardi (Laptop)", "Matt Hughes", 
        "Matthias Drochner", "Matwey V. Kornilov", "Michael Dickens", "Michael Taylor", "Mykyta Sytyi", 
        "Nidroide", "Nir Lichtman", "Oleg Ginzburg", "Oscar Roig Felius", "ParkSangJun", 
        "Patrick", "Pavel Klimenko", "Peter", "Peter Hickey", "Pino Toscano", 
        "Roland Bosa", "Sam Lanning", "Sebastian Jennen", "SilverAstro", "Song Li", 
        "Sripath Roy Koganti", "Sveinn í Felli", "Thilo", "Thomas1664", "Tig la Pomme", 
        "Tomasz Buchert", "TotalCaesar659", "Tuomas Teipainen", "Tēvita O. Kaʻili", "Vancho Stojkoski", 
        "Vicente Reyes", "Wonkyo Choe", "Yaakov Selkowitz", "Youssif Ghantous Filho", "Yury Solomonov", 
        "adalava", "afontenot", "bkuhls", "chithihuynh", "Marc Espie", 
        "leonardcj", "luz paz", "Pavel Klimenko", "rikardfalkeborn", "riodoro1", 
        "Ross Mitchell", "Edgar Scholz", "zhu1995zpb", "Łukasz 'sil2100' Zemczak"
    };
    
}
